# Team and Contact

FABulous is maintained by Professor Dirk Koch's research groups at the [University of Manchester](https://github.com/FPGA-Research) and the [University of Heidelberg](https://www.ziti.uni-heidelberg.de/de/forschung/nct.html).
